#include "app.h"
#include "input.h"
#include "graphics.h"
#include "texturemanager.h"
#include "draw.h"
#include "colour.h"

App::App()
{
};

App::~App()
{
};

bool App::Init()
{
	new Log();
	new Input();
	new Graphics();
	new TextureManager();

	Graphics::GetSingleton().Init(800, 600, 24, SDL_OPENGL | SDL_GL_DOUBLEBUFFER | SDL_HWPALETTE, "S4");
	Graphics::GetSingleton().MakeWindow();
	Graphics::GetSingleton().SetMode(PROJECTION);
	Input::GetSingleton().Start();

	emitter = new Emitter(1000, 5, 30, Vector(30,20,-0), 0, 200);
	emitter->LoadTexture("particle.png");

	MainTimer = new Timer();
	emitter->StartEmitting();
	return true;
};

void App::Run()
{
	while(1)
	{
		if(SDL_QuitRequested() != 0)
			break;

		if(Input::GetSingleton().keyDown(SDLK_ESCAPE) == true)
			break;

		double dt;
		MainTimer->Update();
		Input::GetSingleton().Update();
		if(Input::GetSingleton().keyDown(SDLK_RETURN) == true)
			ForceManager::GetSingleton().AddForce(Vector(400, 300, 0), 30, fUp);

		if(Input::GetSingleton().keyDown(SDLK_c) == true)
		{
			ForceManager::GetSingleton().ClearAllForces();
			PortalManager::GetSingleton().ClearAllPortals();
		}

		if(Input::GetSingleton().keyDown(SDLK_SPACE) == true)
			PortalManager::GetSingleton().AddPortal(Vector(400, 300, 0), 30, WHITE);

		Graphics::GetSingleton().ClearScreen();
		dt = MainTimer->GetDT();

		emitter->Emit(100 * dt);
		emitter->Update(dt);
		Graphics::GetSingleton().SetMode(ORTHOGRAPHIC);

		emitter->Render(false);

		Graphics::GetSingleton().SetMode(END_2D);
		Graphics::GetSingleton().SwapBuffers();

	}
};

bool App::Shutdown()
{
	delete MainTimer;
	delete emitter;
	delete TextureManager::GetSingletonPtr();
	delete Graphics::GetSingletonPtr();
	delete Input::GetSingletonPtr();
	return true;
};
